@@ -1,6 +1,6 @@
 #!/usr/bin/env bash
 # created by Tobias Powalowski <tpowa@archlinux.org>
-# grub-uefi related commands have been copied from grub-mkstandalone and grub-mkrescue scripts in extra/grub2-common package
+# grub-uefi related commands have been copied from grub-mkstandalone and grub-mkrescue scripts in core/grub-common package
 
 [[ -z "${_DO_x86_64}" ]] && _DO_x86_64="1"
 [[ -z "${_DO_i686}" ]] && _DO_i686="1"
@@ -14,9 +14,9 @@ usage () {
 	echo "CREATE ALLINONE USB/CD IMAGES"
 	echo "-----------------------------"
 	echo "Run in archboot x86_64 chroot first ..."
-	echo "create-allinone.sh -t"
+	echo "archboot-allinone.sh -t"
 	echo "Run in archboot 686 chroot then ..."
-	echo "create-allinone.sh -t"
+	echo "archboot-allinone.sh -t"
 	echo "Copy the generated tarballs to your favorite directory and run:"
 	echo "${_BASENAME} -g <any other option>"
 	echo ""
@@ -74,7 +74,7 @@ fi
 # set defaults, if nothing given
 [[ -z "${KERNEL}" ]] && KERNEL="$(uname -r)"
 [[ -z "${LTS_KERNEL}" ]] && LTS_KERNEL="$(cat /lib/modules/extramodules-3.0-lts/version)"
-[[ -z "${RELEASENAME}" ]] && RELEASENAME="2k12-R3"
+[[ -z "${RELEASENAME}" ]] && RELEASENAME="2k12-R4"
 [[ -z "${IMAGENAME}" ]] && IMAGENAME="Archlinux-allinone-$(date +%Y.%m)"
 
 IMAGENAME_OLD="${IMAGENAME}"
